-- Thanks to Fenris_Wolf for rewriting the model loader code!
local MOD_ID = "FRSmallerCars"
local MOD_NAME = "Filibuster Rhymes' Smaller Cars"
local MOD_VERSION = "1.00"
local MOD_AUTHOR = "Filibuster Rhymes"

local dir = getDir(MOD_ID)

-- backwards compatibility
local vehicleLoader = loadStaticZomboidModel
if loadVehicleModel then vehicleLoader = loadVehicleModel end

-- Dont need to call this function manually, use loadVehicle() or loadWheel() below
-- If 'model' or 'texture' are nil, then 'name' is used, saving on retudnant typing.
-- However this expects a standard naming pattern of the files:
-- name is converted to "Vehicles_<NAME>"
-- model is converted to "/media/models/Vehicles_<MODEL>.txt"
-- texture is converted to "/media/textures/Vehicles/vehicle_<TEXTURE>.png"
-- if isVehicle is true, then texture is converted to "/media/textures/Vehicles/vehicle_<TEXTURE>shell.png"
local function loadModel(name, model, texture, isVehicle)
    if not model then model = name end
    if not texture then texture = name end
    local texturePrefix = isVehicle and "shell.png" or ".png"

    -- check which function we need to use to load models
    local loadFunction = isVehicle and vehicleLoader or loadStaticZomboidModel
    loadFunction("Vehicles_" .. name,
        dir.."/media/models/Vehicles_" .. model .. ".txt",
        dir.."/media/textures/Vehicles/vehicle_" .. string.lower(texture) .. texturePrefix)
end


-- this function loads the vehicle model and texture,
local function loadVehicle(name, model, texture)
    loadModel(name, model, texture, true)
end

-- this function loads the wheel models and texture,
local function loadWheel(name, model, texture)
    loadModel(name, model, texture, false)
end


-----------------------------------------------------------
-- add new vehicles and wheels below here:
-----------------------------------------------------------

Events.OnInitWorld.Add(function()
    --CarLights uses the CarLights_Police shell, so manually define it
	loadVehicle("CarLights", nil, "CarLights_Police")
	loadVehicle("CarNormal")
    loadVehicle("CarStationWagon")
    loadVehicle("CarTaxi")
    loadVehicle("LuxuryCar")
    loadVehicle("ModernCar")
    loadVehicle("ModernCar2")
    loadVehicle("OffRoad")
    loadVehicle("SmallCar")
    loadVehicle("SmallCar2")
    loadVehicle("SUV")


    -- add the wheels
    loadWheel("WheelFR01")
    loadWheel("WheelFRS3")
    loadWheel("WheelFRL1")
    loadWheel("WheelFRL2")
	
	print("Mod Loaded: " .. MOD_NAME .. " by " .. MOD_AUTHOR .. " (v" .. MOD_VERSION .. ")")
end)
